@@ -249,6 +249,13 @@ impl Array {
         Array::Bool(this.and(&that))
     }
 
+    /// Element-wise logical and, relative to a constant `other`.
+    pub fn and_const(&self, other: Number) -> Array {
+        let this: ArrayExt<bool> = self.type_cast();
+        let that: ArrayExt<bool> = ArrayExt::from(&[other.cast_into()][..]);
+        Array::Bool(this.and(&that))
+    }
+
     /// Element-wise equality comparison.
     pub fn eq(&self, other: &Array) -> Array {
         use Array::*;
@@ -632,6 +639,13 @@ impl Array {
         Array::Bool(this.or(&that))
     }
 
+    /// Element-wise logical or, relative to a constant `other`.
+    pub fn or_const(&self, other: Number) -> Array {
+        let this: ArrayExt<bool> = self.type_cast();
+        let that: ArrayExt<bool> = ArrayExt::from(&[other.cast_into()][..]);
+        Array::Bool(this.or(&that))
+    }
+
     /// Calculate the cumulative product of this `Array`.
     pub fn product(&self) -> Number {
         use Array::*;
